@@ -142,7 +142,7 @@ async def aiter(list: List):
             yield i.decode("utf-8").replace("\\n", "\\\\n").replace(
                 "\\t", "\\\\t"
             ).encode("utf-8")
-        if isinstance(i, str):
+        elif isinstance(i, str):
             yield i.replace("\\n", "\\\\n").replace("\\t", "\\\\t").encode(
                 "utf-8"
             )
